%define tarname Jinja2

# jinja requires itself ( as python-sphinx use it ) to build doc
%define enable_doc 1

Summary:	Python template engine
Name:		python-jinja2
Version:	2.7.3
Release:	%mkrel 4
Source0:	https://pypi.python.org/packages/source/J/Jinja2/%{tarname}-%{version}.tar.gz
# see https://github.com/mitsuhiko/jinja2/pull/259
Patch0:		99d0f3165ace0befd9eafd661be6e0c23d5f9ba5.patch
# from Debian
Patch1:		fix_CVE-2014-0012.patch	
License:	BSD
Group:		Development/Python
Url:		http://jinja.pocoo.org/
BuildArch:	noarch
# weird, should maybe be removed ( misc ) 17/01/2011
Obsoletes:	python-jinja
BuildRequires:	pkgconfig(python)
BuildRequires:	python-setuptools
BuildRequires:	python-markupsafe
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-markupsafe
%if %enable_doc
BuildRequires:	python-sphinx
%endif
Requires:	python-babel >= 0.8
Requires:	python-markupsafe

%description
Jinja2 is a library for Python 2.4 and onwards that is designed to be
flexible, fast and secure. If you have any exposure to other
text-based template languages, such as Smarty or Django, you should
feel right at home with Jinja2. It's both designer and developer
friendly by sticking to Python's principles and adding functionality
useful for templating environments.

%package -n python3-jinja2
Summary:	General purpose template engine
Group:		Development/Python
Requires:	python3-markupsafe
# babel isn't py3k ready yet, and is only a weak dependency
#Requires:	 python3-babel >= 0.8

%description -n python3-jinja2
Jinja2 is a template engine written in pure Python.  It provides a
Django inspired non-XML syntax but supports inline expressions and an
optional sandboxed environment.

If you have any exposure to other text-based template languages, such
as Smarty or Django, you should feel right at home with Jinja2. It's
both designer and developer friendly by sticking to Python's
principles and adding functionality useful for templating
environments.

%prep
%setup -q -n %{tarname}-%{version}
%patch0 -p1
%patch1 -p1
# cleanup
find . -name '*.pyo' -o -name '*.pyc' -delete

# fix EOL
sed -i 's|\r$||g' LICENSE

rm -rf %{py3dir}
cp -a . %{py3dir}

%build
%{__python} setup.py build 
%if %enable_doc
%make -C docs html PYTHONPATH=$(pwd)
%endif

pushd %{py3dir}
%{__python3} setup.py build
popd

%install
pushd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
popd

%{__python} setup.py install -O1 --skip-build --root %{buildroot}

%__rm -rf docs/_build/html/.buildinfo

%check
make test
pushd %{py3dir}
make test
popd

%files
%doc AUTHORS CHANGES LICENSE 
%if %enable_doc
%doc docs/_build/html
%endif
%doc ext
%doc examples
%{python_sitelib}/*

%files -n python3-jinja2
%doc AUTHORS CHANGES LICENSE
%if %enable_doc 
%doc docs/_build/html
%endif # with_docs
%doc ext
%doc examples
%{python3_sitelib}/*



%changelog
* Wed Oct 15 2014 umeabot <umeabot> 2.7.3-4.mga5
+ Revision: 741538
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.7.3-3.mga5
+ Revision: 728824
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sun Jul 06 2014 philippem <philippem> 2.7.3-1.mga5
+ Revision: 644192
- update to 2.7.3

* Sat May 31 2014 pterjan <pterjan> 2.7.2-3.mga5
+ Revision: 628721
- Rebuild for new Python

* Tue Jan 21 2014 philippem <philippem> 2.7.2-2.mga4
+ Revision: 567351
- fix CVE-2014-0012 in previous CVE-2014-1402 patch

* Sat Jan 11 2014 philippem <philippem> 2.7.2-1.mga4
+ Revision: 566221
- upgrade to 2.7.2 that fix CVE-2014-1402 mga#12265

* Tue Oct 22 2013 umeabot <umeabot> 2.7.1-3.mga4
+ Revision: 543494
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7.1-2.mga4
+ Revision: 498773
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 2.7.1-1.mga4
+ Revision: 471577
- Update to 2.7.1

* Tue Jul 02 2013 philippem <philippem> 2.7-1.mga4
+ Revision: 449666
- Update to 2.7, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 2.5.5-8.mga3
+ Revision: 379029
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Feb 21 2011 ahmad <ahmad> 2.5.5-7.mga1
+ Revision: 55646
- re-enable doc building now that the pythonegg requires/provides are lowercase
  and python-sphinx can be intalled

* Mon Feb 21 2011 ahmad <ahmad> 2.5.5-6.mga1
+ Revision: 55614
- disable doc building
- rebuild to make all pythonegg requires/provides lowercase
- enable building the docs, python-sphinx is available now

* Mon Jan 17 2011 misc <misc> 2.5.5-5.mga1
+ Revision: 21027
- rebuild for python 2.7
- clean versionning, add a comment to the Obsoletes on previous version

* Thu Jan 13 2011 ahmad <ahmad> 2.5.5-4.mga1
+ Revision: 8337
- disable building the docs for now
- imported package python-jinja2


* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 2.5.5-3mdv2011.0
+ Revision: 590403
- reenable doc now python-kinja have compiled for 2.7

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 2.5.5-2mdv2011.0
+ Revision: 590400
- disable doc ( as jinja2 requires itself for that )
- rebuild for python 2.7

* Mon Oct 18 2010 Lev Givon <lev@mandriva.org> 2.5.5-1mdv2011.0
+ Revision: 586681
- Update to 2.5.5.

* Sun Oct 17 2010 Lev Givon <lev@mandriva.org> 2.5.4-1mdv2011.0
+ Revision: 586393
- Update to 2.5.4.

* Wed Aug 18 2010 Lev Givon <lev@mandriva.org> 2.5.2-1mdv2011.0
+ Revision: 571216
- Update to 2.5.2.

* Tue Aug 17 2010 Lev Givon <lev@mandriva.org> 2.5.1-1mdv2011.0
+ Revision: 571048
- Update to 2.5.1.
  Change to noarch because speedups are now in markupsafe package.

* Sun May 30 2010 Lev Givon <lev@mandriva.org> 2.5-1mdv2011.0
+ Revision: 546592
- Update to 2.5.

* Tue Apr 20 2010 Lev Givon <lev@mandriva.org> 2.4.1-1mdv2010.1
+ Revision: 537097
- Update to 2.4.1.

* Mon Mar 15 2010 Lev Givon <lev@mandriva.org> 2.3.1-2mdv2010.1
+ Revision: 519116
- Obsolete python-jinja.

* Fri Feb 19 2010 Frederik Himpe <fhimpe@mandriva.org> 2.3.1-1mdv2010.1
+ Revision: 508510
- Update to new version 2.3.1

* Wed Feb 10 2010 Lev Givon <lev@mandriva.org> 2.3-1mdv2010.1
+ Revision: 503884
- Update to 2.3.

* Thu Nov 12 2009 Lev Givon <lev@mandriva.org> 2.2.1-1mdv2010.1
+ Revision: 465419
- Update to 2.2.1.

* Fri May 22 2009 Lev Givon <lev@mandriva.org> 2.1.1-1mdv2010.0
+ Revision: 378570
- imported package python-jinja2


